---
author: ~anton
published: true
title: nickserv
description: basic information about nickserv registering, logging in, etc.
category: 
    - main
---

Your nick is how people know you. If you register your nick, you can limit access to that nick for you only, and use it over and over. If you don't register, someone else may start using it, or potentially registering it for themselves. By registering and using the same nick for an extended period of time, you'll eventually gain a reputation, and potentially trust among users.

Nick registration functions are handled by a service known as "NickServ", a service used by multiple IRC networks including `tilde.chat`.

Some channels, due to issues such as spam, require you to be registered in order to participate in discussions. One of these examples is `#meta`, one of the main/most active channels on the network.

## Registering

The following is the recommended method to register a new nick. If you have questions or doubts, feel free to contact a tilde.chat network operator (netop).

**1: Select a primary nickname.**
You can check if a nick is registered by running:
```
/msg NickServ info <nickname>
```
I recommend avoiding the name of known projects or corporate entities to avoid conflicts and confusion.

If the nick you want is not what you currently have, run:
```
/nick <NewNick>
```

**2: Register your new nick**
To register your new nick, simply run:
```
/msg NickServ REGISTER YourPassword youremail@example.com
```
Replace `YourPassword` and `youremail@example.com` with your desired email and password.

The email address selected will not be given out by the network staff and is mainly used to help with account recovery, such as if you lose or forget your password.

After you register your nick, you will receive a verification command in an email. Make sure to run it within the specified timeframe so your nick doesn't get dropped.

I do not recommend sharing your nick password with anyone since it can compromise security and make it harder to recover the account.

## Logging in

There are 2 common ways for logging in: SASL and Messaging NickServ. I personally prefer SASL over messaging NickServ.

The below instructions are for Weechat and Irssi. If you're using a different client, [Freenode](https://freenode.net/kb/answer/sasl) offers guides for setting up SASL with various clients.

### Method 1: SASL (Recommended)

The examples use "tilde" for the server name. If you used something different, make sure to type that instead.

#### Weechat
```
/set irc.server.tilde.addresses "irc.tilde.chat/6697"
/set irc.server.tilde.ssl on
/set irc.server.tilde.sasl_mechanism PLAIN
/set irc.server.tilde.sasl_username <nickname>
/set irc.server.tilde.sasl_password <password>
/save
```

#### Irssi
```
/network add -sasl_username <nickname> -sasl_password <password> -sasl_mechanism PLAIN tilde
/server add -auto -net tilde -ssl -ssl_verify irc.tilde.chat 6697
/save 
```

### Method 2: Messaging Nickserv (Not Recommended)

I do not recommend using this method. On any unencrypted connection, your password will be sent in cleartext meaning anyone can intercept it and gain access to your nick. Regardless of your connection, it's always possible to forget the / before msg and accidentally send your password in the channel to everyone else there with you, rather than to NickServ.

If you would still like to log in using this method, run:
```
/msg NickServ IDENTIFY YourPassword
```
Replace `YourPassword` with your account's password.

## Additional Help

For additional help with NickServ, you may always run:
```
/msg NickServ help
```
